@@ -2,7 +2,7 @@ import os
 
 import click
 
-URL_TEMPLATE = "\e]8;;{url}\a{title}\e]8;;\a"
+URL_TEMPLATE = r"\e]8;;{url}\a{title}\e]8;;\a"
 
 def info(msg):
     click.echo(click.wrap_text(msg))
@@ -18,4 +18,5 @@ def paragraph(msg):
 
 def link(url, title):
     string = URL_TEMPLATE.format(url=url, title=click.wrap_text(title))
-    os.system(f'echo -e """{string}"""')
+    string = string.replace('"', "")
+    os.system(f'echo -e "{string}"')
